/*
This file is part of the Notesnook project (https://notesnook.com/)

Copyright (C) 2022 Streetwriters (Private) Limited

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

import React from "react";
import { Text, View } from "react-native";
import Icon from "react-native-vector-icons/MaterialCommunityIcons";
import { useThemeStore } from "../../stores/use-theme-store";
import { SIZE } from "../../utils/size";
import Paragraph from "../ui/typography/paragraph";
import { ProTag } from "./pro-tag";

export const FeatureBlock = ({
  vertical,
  highlight,
  content,
  icon,
  pro,
  proTagBg
}) => {
  const colors = useThemeStore((state) => state.colors);

  return vertical ? (
    <View
      style={{
        flexDirection: "row",
        alignItems: "center",
        paddingHorizontal: 12,
        marginBottom: 10
      }}
    >
      <Icon color={colors.accent} name="check" size={SIZE.lg} />

      <Paragraph
        style={{
          flexWrap: "wrap",
          marginLeft: 5,
          flexShrink: 1
        }}
        size={SIZE.md}
      >
        {content}
      </Paragraph>
    </View>
  ) : (
    <View
      style={{
        height: 100,
        justifyContent: "center",
        padding: 10,
        marginRight: 10,
        borderRadius: 5,
        minWidth: 100
      }}
    >
      <Icon color={colors.icon} name={icon} size={SIZE.xl} />
      <Paragraph size={SIZE.md}>
        <Text style={{ color: colors.accent }}>{highlight}</Text>
        {"\n"}
        {content}
      </Paragraph>

      {pro ? (
        <>
          <View style={{ height: 5 }} />
          <ProTag width={50} size={SIZE.xs} background={proTagBg} />
        </>
      ) : (
        <View
          style={{
            width: 30,
            height: 3,
            marginTop: 10,
            borderRadius: 100,
            backgroundColor: colors.accent
          }}
        />
      )}
    </View>
  );
};
