/*
This file is part of the Notesnook project (https://notesnook.com/)

Copyright (C) 2022 Streetwriters (Private) Limited

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

const fs = require("fs");
const { app } = require("electron");
const path = require("path");

const directory = app.getPath("userData");
const filename = "config.json";
const filePath = path.join(directory, filename);
class JSONStorage {
  static get(key, def) {
    const json = this.readJson();
    return json[key] || def;
  }

  static set(key, value) {
    const json = this.readJson();
    json[key] = value;
    this.writeJson(json);
  }

  static clear() {
    this.writeJson({});
  }

  /**
   * @private
   */
  static readJson() {
    try {
      const json = fs.readFileSync(filePath, "utf-8");
      return JSON.parse(json);
    } catch (e) {
      console.error(e);
      return {};
    }
  }

  /**
   * @private
   */
  static writeJson(json) {
    try {
      fs.writeFileSync(filePath, JSON.stringify(json));
    } catch (e) {
      console.error(e);
    }
  }
}
module.exports = JSONStorage;
